@@ -559,7 +559,7 @@ class VolumeSnapshot(object):
     A base VolumeSnapshot class to derive from.
     """
     def __init__(self, id, driver, size=None, extra=None, created=None,
-                 state=None):
+                 state=None, name=None):
         """
         VolumeSnapshot constructor.
 
@@ -583,6 +583,9 @@ class VolumeSnapshot(object):
         :param      state: A string representing the state the snapshot is
                            in. See `libcloud.compute.types.StorageVolumeState`.
         :type       state: ``str``
+
+        :param      name: A string representing the name of the snapshot
+        :type       name: ``str``
         """
         self.id = id
         self.driver = driver
@@ -590,6 +593,7 @@ class VolumeSnapshot(object):
         self.extra = extra or {}
         self.created = created
         self.state = state
+        self.name = name
 
     def destroy(self):
         """
@@ -600,8 +604,8 @@ class VolumeSnapshot(object):
         return self.driver.destroy_volume_snapshot(snapshot=self)
 
     def __repr__(self):
-        return ('<VolumeSnapshot id=%s size=%s driver=%s state=%s>' %
-                (self.id, self.size, self.driver.name, self.state))
+        return ('<VolumeSnapshot "%s" id=%s size=%s driver=%s state=%s>' %
+                (self.name, self.id, self.size, self.driver.name, self.state))
 
 
 class KeyPair(object):
