@@ -851,7 +851,7 @@ class ECSDriver(NodeDriver):
         List security group attributes in the current region.
 
         :keyword group_id: security group id.
-        :type ex_filters: ``str``
+        :type group_id: ``str``
 
         :keyword nic_type: internet|intranet.
         :type nic_type: ``str``
@@ -872,6 +872,62 @@ class ECSDriver(NodeDriver):
                                namespace=self.namespace)
         return [self._to_security_group_attribute(el) for el in sga_elements]
 
+    def ex_join_security_group(self, node, group_id=None):
+        """
+        Join a node into security group.
+
+        :param node: The node to join security group
+        :type node: :class:`Node`
+
+        :param group_id: security group id.
+        :type group_id: ``str``
+
+
+        :return: join operation result.
+        :rtype: ``bool``
+        """
+        if group_id is None:
+            raise AttributeError('group_id is required')
+
+        if node.state != NodeState.RUNNING and \
+           node.state != NodeState.STOPPED:
+            raise LibcloudError('The node state with id % s need\
+                                be running or stopped .' % node.id)
+
+        params = {'Action': 'JoinSecurityGroup',
+                  'InstanceId': node.id,
+                  'SecurityGroupId': group_id}
+        resp = self.connection.request(self.path, params)
+        return resp.success()
+
+    def ex_leave_security_group(self, node, group_id=None):
+        """
+        Leave a node from security group.
+
+        :param node: The node to leave security group
+        :type node: :class:`Node`
+
+        :param group_id: security group id.
+        :type group_id: ``str``
+
+
+        :return: leave operation result.
+        :rtype: ``bool``
+        """
+        if group_id is None:
+            raise AttributeError('group_id is required')
+
+        if node.state != NodeState.RUNNING and \
+           node.state != NodeState.STOPPED:
+            raise LibcloudError('The node state with id % s need\
+                                be running or stopped .' % node.id)
+
+        params = {'Action': 'LeaveSecurityGroup',
+                  'InstanceId': node.id,
+                  'SecurityGroupId': group_id}
+        resp = self.connection.request(self.path, params)
+        return resp.success()
+
     def ex_list_zones(self, region_id=None):
         """
         List availability zones in the given region or the current region.
@@ -892,7 +948,6 @@ class ECSDriver(NodeDriver):
                                 namespace=self.namespace)
         zones = [self._to_zone(el) for el in zone_elements]
         return zones
-
     ##
     # Volume and snapshot management methods
     ##
